/*
 * Transforms pages[0..length].content from markdown to HTML
 */

var marked = require('marked');
var renderer = new marked.Renderer();
var highlightjs = require('highlight.js');
var path = require('path');
var jobs = require('./jobs');

var toURL = function(url) {
  return jobs.run('toURL', url);
}

renderer.heading = function(text, level, raw) {
  return '<h'  +
    (level+2)  +
    ' id="'    +
    toURL(raw) +
    '">'       +
    text       +
    '</h'      +
    (level+2)  +
    '>\n';
}

renderer.paragraph = function(text) {
  if(text.match('\\<img')) return '<div class="has-image">'+text+'</div>\n';
  else return '<p>'+text+'</p>\n';
}

marked.setOptions({
  renderer: renderer,
  gfm: true,
  tables: true,
  breaks: false,
  pedantic: false,
  sanitize: false,
  smartLists: true,
  smartypants: false,
});

module.exports = function(obj) {
  obj.pages.forEach(function(article) {
    renderer.image = function(href, title, text) {
      href = href.split(path.sep).join('/');
      href = href.split(' =');
      var size = href[1];
      href = href[0];
      var rel = path.relative(process.cwd(),path.resolve(article.filename,href));

      var out = '<img src="' + href + '" alt="' + text + '"';
      if(size !== undefined) {
        size = size.split('x');
        if(size[0].length > 0) {
          out += ' width="' + size[0] + '"';
        }
        if(size.length > 1 && size[1].length > 0) {
          out += ' height="' + size[1] + '"';
        }
      }
      if (title) {
        out += ' title="' + title + '"';
      }

      out += '>';
      if(true) { // if lightbox
        var full = href;
        var a = '<a href="'+full+'"';
        a += ' data-lightbox="group"';
        a += ' data-title="' + text + '"';
        a += '>';
        out = a+out+'</a>';
      }

      return out;
    };

    article.content = marked(article.content, {
      highlight: function (code) {
        var h;
        if(highlightjs.getLanguage(article.metadata.lang))
          h = highlightjs.highlight(article.metadata.lang, code, true);
        else
          h = highlightjs.highlightAuto(code);
        return h.value;
      },
      renderer: renderer
    });
  });
  return Promise.resolve(obj);
}
